/***************************************************************************
                             awayoptionsimp.h
                             -------------------
    begin                : Tuesday Jan 10 2001
    copyright            : (C) 2001 Benjamin Meyer
    email                : benjamin@csh.rit.edu
 ***************************************************************************/


#ifndef AWAYWINDOWOPTIONSIMP_H
#define AWAYWINDOWOPTIONSIMP_H

#include <qwidget.h>
#include <qpushbutton.h>
#include <qcombobox.h>
#include <qspinbox.h>
#include <qcheckbox.h>
#include <awayoptions.h>
#include <setup.h>

/**
 * Allows the user to change their away options and add/remove away messages
 * @author Benjamin Meyer
 */
class AwayWindowOptionsImp : public awayOptions { 

Q_OBJECT

public:
  AwayWindowOptionsImp( QWidget* parent = 0, const char* name = 0);
  void getData();
  void updateData();

private slots:
  void awayMessageSelected(int number);
  void addAwayMessage();
  void newAwayMessage();
  void removeAwayMessage();

private:
  int CurrentSelected;
  /// Pointer to the settings class
  settings_t *i_aimSettings;
	
};

#endif

// awayoptionsimp.h

